@@ -395,11 +395,9 @@ class DiscordWebSocket:
             "d": {
                 "token": self.token,
                 "properties": {
-                    "$os": sys.platform,
-                    "$browser": "pycord",
-                    "$device": "pycord",
-                    "$referrer": "",
-                    "$referring_domain": "",
+                    "os": sys.platform,
+                    "browser": "pycord",
+                    "device": "pycord",
                 },
                 "compress": True,
                 "large_threshold": 250,
