@@ -27,7 +27,8 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+import asyncio
+from typing import TYPE_CHECKING, Any, Coroutine, Dict, List, Optional, Tuple, Union
 
 from . import utils
 from .channel import ChannelType, PartialMessageable
@@ -53,7 +54,7 @@ if TYPE_CHECKING:
 
     from .channel import (
         CategoryChannel,
-        PartialMessageable,
+        ForumChannel,
         StageChannel,
         TextChannel,
         VoiceChannel,
@@ -75,6 +76,7 @@ if TYPE_CHECKING:
         VoiceChannel,
         StageChannel,
         TextChannel,
+        ForumChannel,
         CategoryChannel,
         Thread,
         PartialMessageable,
@@ -134,10 +136,13 @@ class Interaction:
         "token",
         "version",
         "custom_id",
+        "_message_data",
         "_permissions",
+        "_app_permissions",
         "_state",
         "_session",
         "_original_message",
+        "_cs_app_permissions",
         "_cs_response",
         "_cs_followup",
         "_cs_channel",
@@ -161,12 +166,14 @@ class Interaction:
         self.locale: Optional[str] = data.get("locale")
         self.guild_locale: Optional[str] = data.get("guild_locale")
         self.custom_id: Optional[str] = self.data.get("custom_id") if self.data is not None else None
+        self._app_permissions: int = int(data.get("app_permissions", 0))
 
-        self.message: Optional[Message]
-        try:
-            self.message = Message(state=self._state, channel=self.channel, data=data["message"])  # type: ignore
-        except KeyError:
-            self.message = None
+        self.message: Optional[Message] = None
+
+        if (message_data := data.get("message")):
+            self.message = Message(state=self._state, channel=self.channel, data=message_data)
+
+        self._message_data = message_data
 
         self.user: Optional[Union[User, Member]] = None
         self._permissions: int = 0
@@ -179,7 +186,8 @@ class Interaction:
             except KeyError:
                 pass
             else:
-                self.user = Member(state=self._state, guild=guild, data=member)  # type: ignore
+                cache_flag = self._state.member_cache_flags.interaction
+                self.user = guild._get_and_update_member(member, int(member["user"]["id"]), cache_flag)
                 self._permissions = int(member.get("permissions", 0))
         else:
             try:
@@ -229,6 +237,11 @@ class Interaction:
         """
         return Permissions(self._permissions)
 
+    @utils.cached_slot_property("_cs_app_permissions")
+    def app_permissions(self) -> Permissions:
+        """:class:`Permissions`: The resolved permissions of the application in the channel, including overwrites."""
+        return Permissions(self._app_permissions)
+
     @utils.cached_slot_property("_cs_response")
     def response(self) -> InteractionResponse:
         """:class:`InteractionResponse`: Returns an object responsible for handling responding to the interaction.
@@ -424,6 +437,42 @@ class Interaction:
         else:
             await func
 
+    def to_dict(self) -> Dict[str, Any]:
+        """Converts this interaction object into a dict."""
+
+        data = {
+            "id": self.id,
+            "application_id": self.application_id,
+            "type": self.type.value,
+            "token": self.token,
+            "version": self.version,
+        }
+
+        if self.data is not None:
+            data["data"] = self.data
+            if (resolved := self.data.get("resolved")) and self.user is not None:
+                if (users := resolved.get("users")) and (user := users.get(self.user.id)):
+                    data["user"] = user
+                if (members := resolved.get("members")) and (member := members.get(self.user.id)):
+                    data["member"] = member
+
+        if self.guild_id is not None:
+            data["guild_id"] = self.guild_id
+
+        if self.channel_id is not None:
+            data["channel_id"] = self.channel_id
+
+        if self.locale:
+            data["locale"] = self.locale
+
+        if self.guild_locale:
+            data["guild_locale"] = self.guild_locale
+
+        if self._message_data:
+            data["message"] = self._message_data
+
+        return data
+
 
 class InteractionResponse:
     """Represents a Discord interaction response.
@@ -436,11 +485,13 @@ class InteractionResponse:
     __slots__: Tuple[str, ...] = (
         "_responded",
         "_parent",
+        "_response_lock",
     )
 
     def __init__(self, parent: Interaction):
         self._parent: Interaction = parent
         self._responded: bool = False
+        self._response_lock = asyncio.Lock()
 
     def is_done(self) -> bool:
         """:class:`bool`: Indicates whether an interaction response has been done before.
@@ -449,7 +500,7 @@ class InteractionResponse:
         """
         return self._responded
 
-    async def defer(self, *, ephemeral: bool = False) -> None:
+    async def defer(self, *, ephemeral: bool = False, invisible: bool = True) -> None:
         """|coro|
 
         Defers the interaction response.
@@ -457,11 +508,22 @@ class InteractionResponse:
         This is typically used when the interaction is acknowledged
         and a secondary action will be done later.
 
+        This can only be used with the following interaction types:
+        - :attr:`InteractionType.application_command`
+        - :attr:`InteractionType.component`
+        - :attr:`InteractionType.modal_submit`
+
         Parameters
         -----------
         ephemeral: :class:`bool`
             Indicates whether the deferred message will eventually be ephemeral.
-            If ``True`` for interactions of type :attr:`InteractionType.component`, this will defer ephemerally.
+            This only applies to :attr:`InteractionType.application_command` interactions, or if ``invisible`` is ``False``.
+        invisible: :class:`bool`
+            Indicates whether the deferred type should be 'invisible' (:attr:`InteractionResponseType.deferred_message_update`)
+            instead of 'thinking' (:attr:`InteractionResponseType.deferred_channel_message`).
+            In the Discord UI, this is represented as the bot thinking of a response. You must
+            eventually send a followup message via :attr:`Interaction.followup` to make this thinking state go away.
+            This parameter does not apply to interactions of type :attr:`InteractionType.application_command`.
 
         Raises
         -------
@@ -476,25 +538,29 @@ class InteractionResponse:
         defer_type: int = 0
         data: Optional[Dict[str, Any]] = None
         parent = self._parent
-        if parent.type is InteractionType.component:
-            if ephemeral:
-                data = {"flags": 64}
-                defer_type = InteractionResponseType.deferred_channel_message.value
-            else:
-                defer_type = InteractionResponseType.deferred_message_update.value
-        elif parent.type in (InteractionType.application_command, InteractionType.modal_submit):
+        if parent.type is InteractionType.component or parent.type is InteractionType.modal_submit:
+            defer_type = (
+                InteractionResponseType.deferred_message_update.value
+                if invisible
+                else InteractionResponseType.deferred_channel_message.value
+            )
+            if not invisible and ephemeral:
+                data = {'flags': 64}
+        elif parent.type is InteractionType.application_command:
             defer_type = InteractionResponseType.deferred_channel_message.value
             if ephemeral:
-                data = {"flags": 64}
+                data = {'flags': 64}
 
         if defer_type:
             adapter = async_context.get()
-            await adapter.create_interaction_response(
-                parent.id,
-                parent.token,
-                session=parent._session,
-                type=defer_type,
-                data=data,
+            await self._locked_response(
+                adapter.create_interaction_response(
+                    parent.id,
+                    parent.token,
+                    session=parent._session,
+                    type=defer_type,
+                    data=data,
+                )
             )
             self._responded = True
 
@@ -518,11 +584,13 @@ class InteractionResponse:
         parent = self._parent
         if parent.type is InteractionType.ping:
             adapter = async_context.get()
-            await adapter.create_interaction_response(
-                parent.id,
-                parent.token,
-                session=parent._session,
-                type=InteractionResponseType.pong.value,
+            await self._locked_response(
+                adapter.create_interaction_response(
+                    parent.id,
+                    parent.token,
+                    session=parent._session,
+                    type=InteractionResponseType.pong.value,
+                )
             )
             self._responded = True
 
@@ -570,7 +638,7 @@ class InteractionResponse:
             before deleting the message we just sent.
         file: :class:`File`
             The file to upload.
-        files: :class:`List[File]`
+        files: List[:class:`File`]
             A list of files to upload. Must be a maximum of 10.
 
         Raises
@@ -638,13 +706,15 @@ class InteractionResponse:
         parent = self._parent
         adapter = async_context.get()
         try:
-            await adapter.create_interaction_response(
-                parent.id,
-                parent.token,
-                session=parent._session,
-                type=InteractionResponseType.channel_message.value,
-                data=payload,
-                files=files,
+            await self._locked_response(
+                adapter.create_interaction_response(
+                    parent.id,
+                    parent.token,
+                    session=parent._session,
+                    type=InteractionResponseType.channel_message.value,
+                    data=payload,
+                    files=files,
+                )
             )
         finally:
             if files:
@@ -668,6 +738,8 @@ class InteractionResponse:
         content: Optional[Any] = MISSING,
         embed: Optional[Embed] = MISSING,
         embeds: List[Embed] = MISSING,
+        file: File = MISSING,
+        files: List[File] = MISSING,
         attachments: List[Attachment] = MISSING,
         view: Optional[View] = MISSING,
         delete_after: Optional[float] = None,
@@ -686,6 +758,11 @@ class InteractionResponse:
         embed: Optional[:class:`Embed`]
             The embed to edit the message with. ``None`` suppresses the embeds.
             This should not be mixed with the ``embeds`` parameter.
+        file: :class:`File`
+            A new file to add to the message. This cannot be mixed with ``files`` parameter.
+        files: List[:class:`File`]
+            A list of new files to add to the message. Must be a maximum of 10. This
+            cannot be mixed with the ``file`` parameter.
         attachments: List[:class:`Attachment`]
             A list of attachments to keep in the message. If ``[]`` is passed
             then all attachments are removed.
@@ -733,14 +810,44 @@ class InteractionResponse:
         if view is not MISSING:
             state.prevent_view_updates_for(message_id)
             payload["components"] = [] if view is None else view.to_components()
+
+        if file is not MISSING and files is not MISSING:
+            raise InvalidArgument("cannot pass both file and files parameter to edit_message()")
+
+        if file is not MISSING:
+            if not isinstance(file, File):
+                raise InvalidArgument("file parameter must be a File")
+            else:
+                files = [file]
+                if "attachments" not in payload:
+                    # we keep previous attachments when adding a new file
+                    payload["attachments"] = [a.to_dict() for a in msg.attachments]
+
+        if files is not MISSING:
+            if len(files) > 10:
+                raise InvalidArgument("files parameter must be a list of up to 10 elements")
+            elif not all(isinstance(file, File) for file in files):
+                raise InvalidArgument("files parameter must be a list of File")
+            if "attachments" not in payload:
+                # we keep previous attachments when adding new files
+                payload["attachments"] = [a.to_dict() for a in msg.attachments]
+
         adapter = async_context.get()
-        await adapter.create_interaction_response(
-            parent.id,
-            parent.token,
-            session=parent._session,
-            type=InteractionResponseType.message_update.value,
-            data=payload,
-        )
+        try:
+            await self._locked_response(
+                adapter.create_interaction_response(
+                    parent.id,
+                    parent.token,
+                    session=parent._session,
+                    type=InteractionResponseType.message_update.value,
+                    data=payload,
+                    files=files,
+                )
+            )
+        finally:
+            if files:
+                for file in files:
+                    file.close()
 
         if view and not view.is_finished():
             state.store_view(view, message_id)
@@ -780,12 +887,14 @@ class InteractionResponse:
         payload = {"choices": [c.to_dict() for c in choices]}
 
         adapter = async_context.get()
-        await adapter.create_interaction_response(
-            parent.id,
-            parent.token,
-            session=parent._session,
-            type=InteractionResponseType.auto_complete_result.value,
-            data=payload,
+        await self._locked_response(
+            adapter.create_interaction_response(
+                parent.id,
+                parent.token,
+                session=parent._session,
+                type=InteractionResponseType.auto_complete_result.value,
+                data=payload,
+            )
         )
 
         self._responded = True
@@ -812,17 +921,40 @@ class InteractionResponse:
 
         payload = modal.to_dict()
         adapter = async_context.get()
-        await adapter.create_interaction_response(
-            self._parent.id,
-            self._parent.token,
-            session=self._parent._session,
-            type=InteractionResponseType.modal.value,
-            data=payload,
+        await self._locked_response(
+            adapter.create_interaction_response(
+                self._parent.id,
+                self._parent.token,
+                session=self._parent._session,
+                type=InteractionResponseType.modal.value,
+                data=payload,
+            )
         )
         self._responded = True
         self._parent._state.store_modal(modal, self._parent.user.id)
         return self._parent
 
+    async def _locked_response(self, coro: Coroutine[Any]):
+        """|coro|
+
+        Wraps a response and makes sure that it's locked while executing.
+
+        Parameters
+        -----------
+        coro: Coroutine[Any]
+            The coroutine to wrap.
+
+        Raises
+        -------
+        InteractionResponded
+            This interaction has already been responded to before.
+        """
+        async with self._response_lock:
+            if self.is_done():
+                coro.close()  # cleanup unawaited coroutine
+                raise InteractionResponded(self._parent)
+            await coro
+
 
 class _InteractionMessageState:
     __slots__ = ("_parent", "_interaction")
