@@ -657,6 +657,10 @@ class Message(Hashable):
         The guild that the message belongs to, if applicable.
     interaction: Optional[:class:`MessageInteraction`]
         The interaction associated with the message, if applicable.
+    thread: Optional[:class:`Thread`]
+        The thread created from this message, if applicable.
+
+        .. versionadded:: 2.0
     """
 
     __slots__ = (
@@ -691,6 +695,7 @@ class Message(Hashable):
         "components",
         "guild",
         "interaction",
+        "thread",
     )
 
     if TYPE_CHECKING:
@@ -766,6 +771,12 @@ class Message(Hashable):
         except KeyError:
             self.interaction = None
 
+        self.thread: Optional[Thread]
+        try:
+            self.thread = Thread(guild=self.guild, state=self._state, data=data["thread"])
+        except KeyError:
+            self.thread = None
+
         for handler in ("author", "member", "mentions", "mention_roles"):
             try:
                 getattr(self, f"_handle_{handler}")(data[handler])
@@ -1157,7 +1168,7 @@ class Message(Hashable):
         if self.type is MessageType.guild_invite_reminder:
             return "Wondering who to invite?\nStart by inviting anyone who can help you build the server!"
 
-    async def delete(self, *, delay: Optional[float] = None) -> None:
+    async def delete(self, *, delay: Optional[float] = None, reason: Optional[str] = None) -> None:
         """|coro|
 
         Deletes the message.
@@ -1174,6 +1185,8 @@ class Message(Hashable):
         delay: Optional[:class:`float`]
             If provided, the number of seconds to wait in the background
             before deleting the message. If the deletion fails then it is silently ignored.
+        reason: Optional[:class:`str`]
+            The reason for deleting the message. Shows up on the audit log.
 
         Raises
         ------
@@ -1184,7 +1197,7 @@ class Message(Hashable):
         HTTPException
             Deleting the message failed.
         """
-        del_func = self._state.http.delete_message(self.channel.id, self.id)
+        del_func = self._state.http.delete_message(self.channel.id, self.id, reason=reason)
         if delay is not None:
             utils.delay_task(delay, del_func)
         else:
@@ -1196,37 +1209,9 @@ class Message(Hashable):
         *,
         content: Optional[str] = ...,
         embed: Optional[Embed] = ...,
-        file: Optional[File] = ...,
-        attachments: List[Attachment] = ...,
-        suppress: bool = ...,
-        delete_after: Optional[float] = ...,
-        allowed_mentions: Optional[AllowedMentions] = ...,
-        view: Optional[View] = ...,
-    ) -> Message:
-        ...
-
-    @overload
-    async def edit(
-        self,
-        *,
-        content: Optional[str] = ...,
-        embed: Optional[Embed] = ...,
-        files: Optional[List[File]] = ...,
-        attachments: List[Attachment] = ...,
-        suppress: bool = ...,
-        delete_after: Optional[float] = ...,
-        allowed_mentions: Optional[AllowedMentions] = ...,
-        view: Optional[View] = ...,
-    ) -> Message:
-        ...
-
-    @overload
-    async def edit(
-        self,
-        *,
-        content: Optional[str] = ...,
         embeds: List[Embed] = ...,
-        file: File = ...,
+        file: Optional[File] = ...,
+        files: Optional[List[File]] = ...,
         attachments: List[Attachment] = ...,
         suppress: bool = ...,
         delete_after: Optional[float] = ...,
@@ -1289,7 +1274,7 @@ class Message(Hashable):
         allowed_mentions: Optional[:class:`~discord.AllowedMentions`]
             Controls the mentions being processed in this message. If this is
             passed, then the object is merged with :attr:`~discord.Client.allowed_mentions`.
-            The merging behaviour only overrides attributes that have been explicitly passed
+            The merging behavior only overrides attributes that have been explicitly passed
             to the object, otherwise it uses the attributes set in :attr:`~discord.Client.allowed_mentions`.
             If no object is passed at all then the defaults given by :attr:`~discord.Client.allowed_mentions`
             are used instead.
@@ -1346,32 +1331,20 @@ class Message(Hashable):
         if file is not MISSING and files is not MISSING:
             raise InvalidArgument("cannot pass both file and files parameter to edit()")
 
-        if file is not MISSING:
+        if file is not MISSING or files is not MISSING:
+            if file is not MISSING:
+                if not isinstance(file, File):
+                    raise InvalidArgument("file parameter must be of type File")
+                files = [file]
+            else:
+                if len(files) > 10:
+                    raise InvalidArgument("files parameter must be a list of up to 10 elements")
+                elif not all(isinstance(file, File) for file in files):
+                    raise InvalidArgument("files parameter must be a list of File")
+                    
             if "attachments" not in payload:
                 # don't want it to remove any attachments when we just add a new file
                 payload["attachments"] = [a.to_dict() for a in self.attachments]
-            if not isinstance(file, File):
-                raise InvalidArgument("file parameter must be File")
-
-            try:
-                data = await self._state.http.edit_files(
-                    self.channel.id,
-                    self.id,
-                    files=[file],
-                    **payload,
-                )
-            finally:
-                file.close()
-
-        elif files is not MISSING:
-            if len(files) > 10:
-                raise InvalidArgument("files parameter must be a list of up to 10 elements")
-            elif not all(isinstance(file, File) for file in files):
-                raise InvalidArgument("files parameter must be a list of File")
-            if "attachments" not in payload:
-                # don't want it to remove any attachments when we just add a new file
-                payload["attachments"] = [a.to_dict() for a in self.attachments]
-
             try:
                 data = await self._state.http.edit_files(
                     self.channel.id,
@@ -1628,13 +1601,16 @@ class Message(Hashable):
         default_auto_archive_duration: ThreadArchiveDuration = getattr(
             self.channel, "default_auto_archive_duration", 1440
         )
+
         data = await self._state.http.start_thread_with_message(
             self.channel.id,
             self.id,
             name=name,
             auto_archive_duration=auto_archive_duration or default_auto_archive_duration,
         )
-        return Thread(guild=self.guild, state=self._state, data=data)
+
+        self.thread = Thread(guild=self.guild, state=self._state, data=data)
+        return self.thread
 
     async def reply(self, content: Optional[str] = None, **kwargs) -> Message:
         """|coro|
@@ -1750,13 +1726,14 @@ class PartialMessage(Hashable):
     def __init__(self, *, channel: PartialMessageableChannel, id: int):
         if channel.type not in (
             ChannelType.text,
+            ChannelType.voice,
             ChannelType.news,
             ChannelType.private,
             ChannelType.news_thread,
             ChannelType.public_thread,
             ChannelType.private_thread,
         ):
-            raise TypeError(f"Expected TextChannel, DMChannel or Thread not {type(channel)!r}")
+            raise TypeError(f"Expected TextChannel, VoiceChannel, DMChannel or Thread not {type(channel)!r}")
 
         self.channel: PartialMessageableChannel = channel
         self._state: ConnectionState = channel._state
@@ -1812,8 +1789,6 @@ class PartialMessage(Hashable):
 
         Edits the message.
 
-        The content must be able to be transformed into a string via ``str(content)``.
-
         .. versionchanged:: 1.7
             :class:`discord.Message` is returned instead of ``None`` if an edit took place.
 
@@ -1822,9 +1797,13 @@ class PartialMessage(Hashable):
         content: Optional[:class:`str`]
             The new content to replace the message with.
             Could be ``None`` to remove the content.
-        embed: Optional[:class:`Embed`]
+        embed: Optional[:class:`~discord.Embed`]
             The new embed to replace the original with.
             Could be ``None`` to remove the embed.
+        embeds: Optional[List[:class:`~discord.Embed`]]
+            A list of embeds to upload. Must be a maximum of 10.
+
+            .. versionadded:: 2.0
         suppress: :class:`bool`
             Whether to suppress embeds for the message. This removes
             all the embeds if set to ``True``. If set to ``False``
@@ -1837,7 +1816,7 @@ class PartialMessage(Hashable):
         allowed_mentions: Optional[:class:`~discord.AllowedMentions`]
             Controls the mentions being processed in this message. If this is
             passed, then the object is merged with :attr:`~discord.Client.allowed_mentions`.
-            The merging behaviour only overrides attributes that have been explicitly passed
+            The merging behavior only overrides attributes that have been explicitly passed
             to the object, otherwise it uses the attributes set in :attr:`~discord.Client.allowed_mentions`.
             If no object is passed at all then the defaults given by :attr:`~discord.Client.allowed_mentions`
             are used instead.
@@ -1863,53 +1842,46 @@ class PartialMessage(Hashable):
             The message that was edited.
         """
 
-        try:
-            content = fields["content"]
-        except KeyError:
-            pass
-        else:
-            if content is not None:
-                fields["content"] = str(content)
+        content = fields.pop("content", MISSING)
+        if content is not MISSING:
+            fields["content"] = str(content) if content is not None else None
 
-        try:
-            embed = fields["embed"]
-        except KeyError:
-            pass
-        else:
-            if embed is not None:
-                fields["embed"] = embed.to_dict()
+        embed = fields.pop("embed", MISSING)
+        embeds = fields.pop("embeds", MISSING)
 
-        try:
-            suppress: bool = fields.pop("suppress")
-        except KeyError:
-            pass
-        else:
-            flags = MessageFlags._from_value(0)
-            flags.suppress_embeds = suppress
-            fields["flags"] = flags.value
+        if embed is not MISSING and embeds is not MISSING:
+            raise InvalidArgument("Cannot pass both embed and embeds parameters.")
+
+        if embed is not MISSING:
+            fields["embeds"] = [embed.to_dict()]
+
+        if embeds is not MISSING:
+            fields["embeds"] = [embed.to_dict() for embed in embeds]
+
+        suppress = fields.pop("suppress", False)
+        flags = MessageFlags._from_value(0)
+        flags.suppress_embeds = suppress
+        fields["flags"] = flags.value
 
         delete_after = fields.pop("delete_after", None)
 
-        try:
-            allowed_mentions = fields.pop("allowed_mentions")
-        except KeyError:
-            pass
+        allowed_mentions = fields.get("allowed_mentions", MISSING)
+        if allowed_mentions is not MISSING:
+            if self._state.allowed_mentions is not None:
+                allowed_mentions = self._state.allowed_mentions.merge(allowed_mentions).to_dict()
+            else:
+                allowed_mentions = allowed_mentions.to_dict()
+            fields["allowed_mentions"] = allowed_mentions
         else:
-            if allowed_mentions is not None:
-                if self._state.allowed_mentions is not None:
-                    allowed_mentions = self._state.allowed_mentions.merge(allowed_mentions).to_dict()
-                else:
-                    allowed_mentions = allowed_mentions.to_dict()
-                fields["allowed_mentions"] = allowed_mentions
+            fields["allowed_mentions"] = (
+                self._state.allowed_mentions.to_dict() if self._state.allowed_mentions else None
+            )
 
-        try:
-            view = fields.pop("view")
-        except KeyError:
-            # To check for the view afterwards
-            view = None
-        else:
+        view = fields.pop("view", MISSING)
+        if view is not MISSING:
             self._state.prevent_view_updates_for(self.id)
             fields["components"] = view.to_components() if view else []
+
         if fields:
             data = await self._state.http.edit_message(self.channel.id, self.id, **fields)
 
