@@ -1,6 +1,5 @@
 """
-    ~   Tracing    ~
-    This modules containes functions and classes
+    This modules contains functions and classes
     related to the console debug long or trace.
 """
 from enum import Enum, auto
@@ -12,12 +11,15 @@ __all__ = (
     "trace"
 )
 
-m_use_debug = None
-m_lock = Lock()
+class GLOBALS:
+    use_debug = None
+    lock = Lock() # For print thread safety
 
 class TraceLEVELS(Enum):
     """
-    Info: Level of trace for debug
+    Levels of trace for debug.
+
+    .. seealso:: :ref:`trace`
     """
     NORMAL = 0
     WARNING = auto()
@@ -25,14 +27,18 @@ class TraceLEVELS(Enum):
 
 def trace(message: str,
           level:   TraceLEVELS = TraceLEVELS.NORMAL):
-    """"
-    Name : trace
-    Param:
-    - message : str          = Trace message
-    - level   : TraceLEVELS = Level of the trace
     """
-    if m_use_debug:
-        with m_lock:
+    Prints a trace to the console.
+    
+    Parameters
+    --------------
+    message: str
+        Trace message.
+    level: TraceLEVELS
+        Level of the trace. Defaults to TraceLEVELS.NORMAL.
+    """
+    if GLOBALS.use_debug:
+        with GLOBALS.lock:
             timestruct = time.localtime()
             timestamp = "Date: {:02d}.{:02d}.{:04d} Time:{:02d}:{:02d}"
             timestamp = timestamp.format(timestruct.tm_mday,
@@ -42,3 +48,17 @@ def trace(message: str,
                                         timestruct.tm_min)
             l_trace = f"{timestamp}\nTrace level: {level.name}\nMessage: {message}\n"
             print(l_trace)
+
+
+def initialize(enable: bool):
+    """
+    Initializes the tracing module
+    
+    Parameters
+    ------------
+    enable: bool
+        True for tracing module to be enabled.
+    """
+    GLOBALS.use_debug = enable
+
+    
\ No newline at end of file
